summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneylineedit.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:31:01 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:31:01 -0600
commit252fce5a2a5384702fbcc1c9987284d7bd2e6943 (patch)
treed5768ff1e9065f29bec60c94d31880b38b4e82f2 /kmymoney2/widgets/kmymoneylineedit.h
parent69ef6c4beaa37474a2170d0bfe842de647f53102 (diff)
downloadkmymoney-252fce5a2a5384702fbcc1c9987284d7bd2e6943.tar.gz
kmymoney-252fce5a2a5384702fbcc1c9987284d7bd2e6943.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'kmymoney2/widgets/kmymoneylineedit.h')
-rw-r--r--kmymoney2/widgets/kmymoneylineedit.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kmymoney2/widgets/kmymoneylineedit.h b/kmymoney2/widgets/kmymoneylineedit.h
index e97205d..f0331f6 100644
--- a/kmymoney2/widgets/kmymoneylineedit.h
+++ b/kmymoney2/widgets/kmymoneylineedit.h
@@ -51,11 +51,11 @@ public:
* @param w pointer to parent
* @param name pointer to name of object
* @param forceMonetaryDecimalSymbol if @a true, the numeric keypad comma key will have a fixed
* value and does not follow the keyboard tqlayout (default: @p false)
* @param tqalignment Controls the tqalignment of the text. Default is TQt::AlignLeft | TQt::AlignVCenter.
* See TQt::AlignmentFlags for other possible values.
*/
- kMyMoneyLineEdit(TQWidget *w = 0, const char* name = 0, bool forceMonetaryDecimalSymbol = false, int tqalignment = (AlignLeft | AlignVCenter));
+ kMyMoneyLineEdit(TQWidget *w = 0, const char* name = 0, bool forceMonetaryDecimalSymbol = false, int alignment = (AlignLeft | AlignVCenter));
~kMyMoneyLineEdit();
/**
@@ -91,7 +91,7 @@ protected:
* out the currently selected monetary decimal symbol instead of the
* key defined by the keymap.
*
- * Example: If you have set the keymap (keyboard tqlayout) as English, then
+ * Example: If you have set the keymap (keyboard layout) as English, then
* the numeric keypad will send a period but if you have set the keymap to
* be German, the same key will send a comma.
*
@@ -104,7 +104,7 @@ protected:
* out the currently selected monetary decimal symbol instead of the
* key defined by the keymap.
*
- * Example: If you have set the keymap (keyboard tqlayout) as English, then
+ * Example: If you have set the keymap (keyboard layout) as English, then
* the numeric keypad will send a period but if you have set the keymap to
* be German, the same key will send a comma.
*
@@ -51,11 +51,11 @@ public:
* @param name pointer to name of object
* @param forceMonetaryDecimalSymbol if @a true, the numeric keypad comma key will have a fixed
- * value and does not follow the keyboard tqlayout (default: @p false)
- * @param tqalignment Controls the tqalignment of the text. Default is TQt::AlignLeft | TQt::AlignVCenter.
+ * value and does not follow the keyboard layout (default: @p false)
+ * @param alignment Controls the alignment of the text. Default is TQt::AlignLeft | TQt::AlignVCenter.
* See TQt::AlignmentFlags for other possible values.
*/